@@ -8,9 +8,9 @@ from azure.storage.blob import ContainerClient
 from azure.core.exceptions import ResourceNotFoundError
 
 
-class CustomAzureReader():
+class CustomAzureReader:
     """
-        Custom Azure Reader
+    Custom Azure Reader
     """
 
     # pylint: disable=super-init-not-called
@@ -18,9 +18,7 @@ class CustomAzureReader():
         self.container_client = self.get_container_client(sas_token_path)
 
     @staticmethod
-    def get_container_client(
-            sas_token_path
-    ):
+    def get_container_client(sas_token_path):
         """
         Create a client to communicate with Sailthru
         Args:
@@ -31,22 +29,21 @@ class CustomAzureReader():
         with open(sas_token_path) as json_file:
             data = json.load(json_file)
 
-        return ContainerClient.from_container_url(data['sas_token'])
+        return ContainerClient.from_container_url(data["sas_token"])
 
     def pull_file(self, file_name):
         """
-            Pulls the data file from Azure blob
-            :return: storage downloader object
+        Pulls the data file from Azure blob
+        :return: storage downloader object
         """
         try:
             byte_sequence = self.container_client.download_blob(file_name).readall()
             return json.loads(byte_sequence.decode("utf-8"))
         except ResourceNotFoundError as exception:
             print(
-                'Could not find specified blob: {exception}'.format(
+                "Could not find specified blob: {exception}".format(
                     exception=str(exception)
                 )
             )
 
             return None
-
