@@ -14,6 +14,7 @@ class CustomFalconReader:
     """
     Custom Falcon Reader
     """
+
     def __init__(self, creds_file, config_file=None):
         self._creds = load_file(creds_file, "yml")
         self._config = load_file(config_file, "yml")
@@ -99,8 +100,10 @@ class CustomFalconReader:
         channel_ids = self._get_channel_ids()
         print(f"Attempting to gather metrics from {len(channel_ids)} channel ids.")
         for date in date_range(
-                start_date=date_handler(self._config.get("since", None), "%Y-%m-%d"),
-                end_date=date_handler(self._config.get("until", None), "%Y-%m-%d"),
+            start_date=date_handler(self._config.get("since", None), "%Y-%m-%d"),
+            end_date=date_handler(self._config.get("until", None), "%Y-%m-%d"),
         ):
             for channel_id in channel_ids:
-                self._get_content_metrics_by_channel_ids(channel_id=channel_id, date=date)
+                self._get_content_metrics_by_channel_ids(
+                    channel_id=channel_id, date=date
+                )
