@@ -41,9 +41,7 @@ class GAV3Reader:
             scopes=self.scopes,
             service_account_email=self.service_account_email,
         )
-
         service = build(serviceName="analytics", version="v3", credentials=credentials)
-
         return service
 
     @staticmethod
@@ -53,13 +51,11 @@ class GAV3Reader:
         """
         headers = [head["name"] for head in report["columnHeaders"]]
         profile = report["profileInfo"]
-
         data_set = []
         for row in report["rows"]:
             tmp = dict(zip(headers, row))
             tmp.update(profile)
             data_set.append(tmp)
-
         return data_set
 
     @request_handler(wait=1, backoff_factor=0.5)
@@ -67,13 +63,15 @@ class GAV3Reader:
         exceptions=(socket.timeout, HttpError),
         total_tries=5,
         initial_wait=60,
-        backoff_factor=5,
+        backoff_factor=2,
     )
-    def _query_handler(self, view_id, service, start_index, date):
+    def _query_handler(self, view_id, start_index, date):
         """
         Separated query method to handle retry and delay methods.
         """
         print(f"Querying View ID: {view_id}. At index: {start_index}.")
+        # frequently rebuild the service
+        service = self._get_service()
         response = (
             service.data()
             .ga()
@@ -134,15 +132,14 @@ class GAV3Reader:
               Analytics view (profile) ID for which the query will retrieve the data.
         """
         for view_id in self.config.get("view_ids"):
-            service = self._get_service()  # new service for each view_id
             for date in date_range(
                 self.config.get("start_date"), self.config.get("end_date")
             ):
+                date_dataset = []
                 print(f"Gathering data for {view_id} at date: {date}.")
                 page_token = 1  # handle paging of response
                 while True:
                     response = self._query_handler(
-                        service=service,
                         view_id=view_id,
                         start_index=page_token,
                         date=date,
@@ -151,7 +148,12 @@ class GAV3Reader:
                         print("No more data in response.")
                         break
                     page_token += response.get("itemsPerPage", 0)
-                    yield self._normalize_data(response)
+
+                    date_dataset.append(self._normalize_data(response))
+
+                # generator preserves memory, additional data provided
+                # to efficiently partition to s3
+                yield {"data": date_dataset[0], "date": date, "view_id": view_id}
 
 
 class BaseGAV4Reader:
