@@ -42,7 +42,7 @@ class CustomGSCReader:
         self.data_set = []
 
     def generate_authentication(
-            self, auth_file_location="gsc_credentials.pickle"
+        self, auth_file_location="gsc_credentials.pickle"
     ) -> None:
         """
         A user friendly method to generate a .pickle file for future authentication.
@@ -122,8 +122,7 @@ class CustomGSCReader:
                             "metrics": self.config.get("metrics"),
                             "type": self.config.get("type"),
                             "rowLimit": self.config.get("row_limit", 25000),
-                            "startRow": row_index
-                                        * self.config.get("row_limit", 25000),
+                            "startRow": row_index * self.config.get("row_limit", 25000),
                             "aggregationType": self.config.get(
                                 "aggregation_type", "auto"
                             ),
@@ -146,7 +145,8 @@ class CustomGSCReader:
                     for row in response["rows"]:
                         dataset = {
                             "site_url": self.config.get("site_url"),
-                            "search_type": self.config.get("search_type"),
+                            # keeping original search_type name for reporting
+                            "search_type": self.config.get("type"),
                         }
 
                         # get dimension data keys and values
