@@ -83,12 +83,21 @@ class CustomOneSignalReader:
                     self.data_set = data_frame.to_dict(orient="records")
 
                     # create a usable field to write to s3
+                    # also handle timestamps that have milliseconds, it's not
+                    # always there, so we need to handle both
                     for row in self.data_set:
-                        row["created_at_date"] = str(
-                            datetime.strptime(
-                                row["created_at"], "%Y-%m-%d %H:%M:%S"
-                            ).date()
-                        ).replace("-", "")
+                        try:
+                            row["created_at_date"] = str(
+                                datetime.strptime(
+                                    row["created_at"], "%Y-%m-%d %H:%M:%S"
+                                ).date()
+                            ).replace("-", "")
+                        except ValueError:
+                            row["created_at_date"] = str(
+                                datetime.strptime(
+                                    row["created_at"], "%Y-%m-%d %H:%M:%S.%f"
+                                ).date()
+                            ).replace("-", "")
 
                     print("Data gathered...")
                     return self.data_set
